v0.2.0
======

Added backward compatibility for EntryPoint objects as found in
older importlib metadata implementations.

v0.1.0
======

Experimental initial implementation. Supplies ``check`` function
for checking an ep for validity.
